@@ -2,6 +2,7 @@
 context("Simulator object creation")
 
 test_that("Argument checking works", {
+  skip_if_not_installed("pomp")
   with_mock(requireNamespace = function(package, ..., quietly=FALSE) FALSE,
             expect_error(create_simulator(),
                          regexp="The pomp package is needed"))
@@ -16,9 +17,26 @@ test_that("Argument checking works", {
 
 context("Gillespie direct method simulator")
 
+test_that("Calculation of cases consistent with number of recovered", {
+  skip_if_not_installed("pomp")
+
+  params <- c(gamma=24, mu=0.014, d=0.0, eta=1e-4, beta=24e-2,
+              rho=0.9, S_0=1, I_0=0, R_0=0, N_0=1e2)
+  covar <- data.frame(gamma_t=c(0, 0), mu_t=c(0, 0), d_t=c(0, 0),
+                      eta_t=c(0, 0), beta_t=c(0, 0), time=c(0, 1e6))
+  times <- seq(0, 1000, by=1)
+
+  sim <- create_simulator(params=params, times=times, covar=covar,
+                          process_model="SIR")
+  so <- pomp::simulate(sim, as.data.frame=TRUE, seed=200)
+  expect_equal(diff(so$R), so$cases[-1])
+})
+
 test_that(paste("Mean and stddev of stationary model over time",
                 "consistent with ensemble mean and stdev of dizzy",
                 "progam's implementation"), {
+  skip_if_not_installed("pomp")
+  skip_on_cran()
 
   params <- c(gamma=24, mu=0.014, d=0.014, eta=1e-4, beta=24e-2,
               rho=0.9, S_0=1, I_0=0, R_0=0, N_0=1e2)
@@ -38,6 +56,8 @@ test_that(paste("Mean and stddev of stationary model over time",
 test_that(paste("Means and final stddev of time-dependent model",
                 "consistent with ensemble mean and stdev of dizzy",
                 "progam's implementation"), {
+  skip_if_not_installed("pomp")
+  skip_on_cran()
 
   params <- c(gamma=24, mu=0.014, d=0.014, eta=1e-4, beta=0e-2,
               rho=0.9, S_0=1, I_0=0, R_0=0, N_0=1e2)
@@ -97,6 +117,8 @@ test_that(paste("Means and final stddev of time-dependent model",
 
 test_that(paste("Fluctuations for large system sizes approximate AR process",
                 "given by linear noise approximation"), {
+  skip_if_not_installed("pomp")
+  skip_on_cran()
 
   params <- c(gamma=16.59091, mu=0.02, d=0.02, eta=2e-4, beta=100e-6,
               rho=0.9, S_0=0.165779, I_0=0.001004, R_0=0.833216, N_0=1e6)
